@@ -1,7 +1,7 @@
 /***************************************************************************
                           qaview.cpp  -  description
                              -------------------
-   copyright            : (C) 2003-2008 Peter Hedlund
+   copyright            : (C) 2003-2009 Peter Hedlund
    email                : peter.hedlund@kdemail.net
  ***************************************************************************/
 
@@ -16,13 +16,15 @@
 
 #include "qaview.h"
 
+#include <QtDBus/QDBusInterface>
+
 #include <KIconLoader>
 #include <KLocale>
 #include <KNotification>
 
 #include "prefs.h"
-#include "kwqquiz.h"
-#include "wqscore.h"
+#include "kwqquizmodel.h"
+#include "kwqscorewidget.h"
 
 QString highlightError(const QString & c, const QString & e)
 {
@@ -64,34 +66,29 @@ QAView::QAView(QWidget *parent, KActionCollection * actionCollection) : QWidget(
   setupUi(this);
 
   connect(txtAnswer, SIGNAL(returnPressed()), this, SLOT(slotCheck()));
-
-  m_score = new WQScore();
 }
 
-void QAView::setQuiz(KWQQuiz *quiz)
+void QAView::setQuiz(KWQQuizModel *quiz)
 {
   m_quiz = quiz;
 }
 
 void QAView::init()
 {
-  m_score -> setQuestionCount(m_quiz->questionCount());
-  m_score -> setAsPercent(Prefs::percent());
+  score->clear();
+  score->setQuestionCount(m_quiz->questionCount());
+  score->setAsPercent(Prefs::percent());
+
   m_hintUsed = false;
-  m_question = 0;
-  m_error = 0;
-  picAnswered -> clear();
-  picCorrect -> clear();
-  picError -> clear();
 
   QFont f = Prefs::editorFont();
   f.setWeight(QFont::Normal);
-  lblQuestion -> setFont(f);
-  lblAnswerBlank -> setFont(f);
-  txtAnswer -> setFont(f);
-  lblPreviousQuestion -> setFont(f);
-  lblYourAnswer -> setFont(f);
-  lblCorrect -> setFont(f);
+  lblQuestion->setFont(f);
+  lblAnswerBlank->setFont(f);
+  txtAnswer->setFont(f);
+  lblPreviousQuestion->setFont(f);
+  lblYourAnswer->setFont(f);
+  lblCorrect->setFont(f);
 
   lblPreviousQuestionHeader->clear();
   lblPreviousQuestion->clear();
@@ -109,8 +106,7 @@ void QAView::init()
   m_actionCollection->action("quiz_repeat_errors")->setEnabled(false);
   m_actionCollection->action("quiz_export_errors")->setEnabled(false);
 
-  updateScore();
-  showQuestion(0);
+  showQuestion();
   txtAnswer->show();
   txtAnswer->setFocus();
 }
@@ -124,60 +120,56 @@ void QAView::slotCheck()
     if (m_hintUsed && Prefs::hintError())
     {
       //Force an Error
-      fIsCorrect = m_quiz->checkAnswer(m_question, "");
+      fIsCorrect = m_quiz->checkAnswer("");
     }
     else
     {
       //Really check the answer
-      fIsCorrect = m_quiz->checkAnswer(m_question, txtAnswer->text());
+      fIsCorrect = m_quiz->checkAnswer(txtAnswer->text());
     }
     //Reset for next question
     m_hintUsed = false;
 
     if (fIsCorrect)
     {
-
       picYourAnswer->setPixmap(KIconLoader::global()->loadIcon("answer-correct", KIconLoader::Panel));
       lblYourAnswer->setText(m_quiz->yourAnswer(txtAnswer->text()));
       lblCorrectHeader->clear();
       picCorrectAnswer->clear();
       lblCorrect->clear();
-      m_score->countIncrement(WQScore::cdCorrect);
-      updateScore();
+      score->countIncrement(KWQScoreWidget::cdCorrect);
       KNotification::event("QuizCorrect", i18n("Your answer was correct!"));
     }
     else
     {
-      m_error++;
-
       picYourAnswer->setPixmap(KIconLoader::global()->loadIcon("error", KIconLoader::Panel));
-      lblYourAnswer->setText(highlightError(m_quiz->answer(m_question), m_quiz->yourAnswer(txtAnswer->text())));
-      lblCorrect->setText(m_quiz->answer(m_question));
+      lblYourAnswer->setText(highlightError(m_quiz->answer(), m_quiz->yourAnswer(txtAnswer->text())));
+      lblCorrect->setText(m_quiz->answer());
       picCorrectAnswer->setPixmap(KIconLoader::global()->loadIcon("answer-correct", KIconLoader::Panel));
       lblCorrectHeader->setText(i18n("Correct Answer"));
-      m_score->countIncrement(WQScore::cdError);
-      updateScore();
+      score->countIncrement(KWQScoreWidget::cdError);
       KNotification::event("QuizError", i18n("Your answer was incorrect."));
     }
 
     lblPreviousQuestionHeader->setText(i18n("Previous Question"));
-    lblPreviousQuestion->setText(m_quiz->question(m_question));
+    lblPreviousQuestion->setText(m_quiz->question());
     //lblPreviousQuestion->setFont(m_quiz->fontQuestion(m_question));
     picPrevious->setPixmap(KIconLoader::global()->loadIcon("question", KIconLoader::Panel));
 
     lblYourAnswerHeader->setText(i18n("Your Answer"));
 
-    if (++m_question < m_quiz->questionCount())
+    m_quiz->toNext();
+    if (!m_quiz->atEnd())
     {
-      showQuestion(m_question);
+      showQuestion();
     }
     else
     {
       m_quiz->finish();
       m_actionCollection->action("quiz_check")->setEnabled(false);
       m_actionCollection->action("qa_hint")->setEnabled(false);
-      m_actionCollection->action("quiz_repeat_errors")->setEnabled((m_error > 0));
-      m_actionCollection->action("quiz_export_errors")->setEnabled((m_error > 0));
+      m_actionCollection->action("quiz_repeat_errors")->setEnabled(m_quiz->hasErrors());
+      m_actionCollection->action("quiz_export_errors")->setEnabled(m_quiz->hasErrors());
 
       lblQuestionLanguage->setText(i18n("Summary"));
       lblQuestion->clear();
@@ -193,7 +185,7 @@ void QAView::slotCheck()
 void QAView::slotHint()
 {
   QString answer = txtAnswer->text();
-  QString correctAnswer = m_quiz->hint(m_question);
+  QString correctAnswer = m_quiz->hint();
   if (correctAnswer.left(4) == "<qt>")
   {
     correctAnswer = correctAnswer.remove("<qt>");
@@ -231,61 +223,42 @@ void QAView::slotRepeat()
   init();
 }
 
-void QAView::updateScore()
-{
-  QString s;
-  s = s.setNum(m_quiz->questionCount(), 10);
-  lblScoreCount->setText(s);
-  picCount->setPixmap(KIconLoader::global()->loadIcon("kwordquiz", KIconLoader::Panel));
-
-  s = m_score->answerText();
-  lblScoreAnswered->setText(s);
-  if (!s.isEmpty())
-    picAnswered->setPixmap(KIconLoader::global()->loadIcon("question", KIconLoader::Panel));
-
-  s = m_score->correctText();
-  lblScoreCorrect->setText(s);
-  if (!s.isEmpty())
-    picCorrect->setPixmap(KIconLoader::global()->loadIcon("answer-correct", KIconLoader::Panel));
-
-  s = m_score->errorText();
-  lblScoreError->setText(s);
-  if (!s.isEmpty())
-    picError->setPixmap(KIconLoader::global()->loadIcon("error", KIconLoader::Panel));
-}
-
 
 /*!
     \fn QAView::showQuestion(int i)
  */
-void QAView::showQuestion(int i)
+void QAView::showQuestion()
 {
-  lblQuestionLanguage -> setText(m_quiz ->langQuestion(i));
-  lblQuestion -> setText(m_quiz ->question(i));
+  lblQuestionLanguage->setText(m_quiz ->langQuestion());
+  lblQuestion->setText(m_quiz ->question());
 
-  picQuestion->setPixmap(KIconLoader::global()->loadIcon(m_quiz->quizIcon(i, KWQQuiz::IconLeftCol), KIconLoader::Panel));
+  picQuestion->setPixmap(KIconLoader::global()->loadIcon(m_quiz->quizIcon(KWQQuizModel::IconLeftCol), KIconLoader::Panel));
 
-  lblAnswerLanguage -> setText(m_quiz ->langAnswer(i));
+  lblAnswerLanguage->setText(m_quiz ->langAnswer());
 
-  if (!QString(m_quiz ->blankAnswer(i)).isEmpty())
+  if (!QString(m_quiz->blankAnswer()).isEmpty())
   {
     lblAnswerBlank->show();
-    lblAnswerBlank->setText(m_quiz->blankAnswer(i));
+    lblAnswerBlank->setText(m_quiz->blankAnswer());
   }
   else
     lblAnswerBlank->hide();
 
-  txtAnswer -> setText("");
+  txtAnswer->setText("");
 
-  picAnswer->setPixmap(KIconLoader::global()->loadIcon(m_quiz->quizIcon(i, KWQQuiz::IconRightCol), KIconLoader::Panel));
+  picAnswer->setPixmap(KIconLoader::global()->loadIcon(m_quiz->quizIcon(KWQQuizModel::IconRightCol), KIconLoader::Panel));
 
-  ///@todo handle keyboard layouts
+  QString layout = m_quiz->kbAnswer();
+  if (!layout.isEmpty()) {
+    QDBusInterface kxkb("org.kde.kxkb", "/kxkb", "org.kde.KXKB");
+    if (kxkb.isValid())
+      kxkb.call("setLayout", layout);
+  }
 }
 
 void QAView::slotApplySettings( )
 {
-  m_score ->setAsPercent(Prefs::percent());
-  updateScore();
+  score->setAsPercent(Prefs::percent());
 }
 
 void QAView::slotSpecChar( const QChar & c)
