@@ -5,7 +5,7 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008-2009    Torsten Rahn <tackat@kde.org>"
+// Copyright 2008-2009    Torsten Rahn <tackat@kde.org>
 //
 
 //
@@ -23,7 +23,8 @@ namespace Marble
 {
 
 
-class MarbleGlobalPrivate {
+class MarbleGlobalPrivate
+{
  public:
     MarbleGlobalPrivate();
     virtual ~MarbleGlobalPrivate();
