@@ -10,9 +10,7 @@
 
 #include "GpsdConnection.h"
 
-#include <QtCore/QDebug>
-
-
+#include "MarbleDebug.h"
 
 using namespace Marble;
 
@@ -22,14 +20,25 @@ GpsdConnection::GpsdConnection( QObject* parent )
 {
     gps_data_t* data = m_gpsd.open();
     if ( data ) {
+#if defined( GPSD_API_MAJOR_VERSION ) && ( GPSD_API_MAJOR_VERSION == 3 || GPSD_API_MAJOR_VERSION == 4 ) && defined( WATCH_ENABLE ) 
+        m_gpsd.stream( WATCH_ENABLE );
+#endif
         connect( &m_timer, SIGNAL( timeout() ), this, SLOT( update() ) );
         m_timer.start( 1000 );
     } else
-        qDebug() << "Connection to gpsd failed, no position info available.";
+        mDebug() << "Connection to gpsd failed, no position info available.";
 }
 
-void GpsdConnection::update() {
-    gps_data_t* data = m_gpsd.query( "o" );
+void GpsdConnection::update()
+{
+    gps_data_t* data = 0;
+#if defined( GPSD_API_MAJOR_VERSION ) && ( GPSD_API_MAJOR_VERSION == 3 || GPSD_API_MAJOR_VERSION == 4 ) && defined( POLICY_SET )
+    while ((data = m_gpsd.poll()) && !(data->set & POLICY_SET)) {
+        data = m_gpsd.poll();
+    }
+#else
+    data = m_gpsd.query( "o" );
+#endif
     if ( data )
         emit gpsdInfo( *data );
 }
