@@ -1,7 +1,7 @@
 /***************************************************************************
     Copyright 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
     Copyright 2004-2007 Peter Hedlund <peter.hedlund@kdemail.net>
-    Copyright 2007-2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+    Copyright 2007-2009 Frederik Gladhorn <gladhorn@kde.org>
     Copyright 2008 Daniel Laidig <d.laidig@gmx.de>
 ***************************************************************************/
 
@@ -27,8 +27,8 @@
 #include "vocabulary/containermodel.h"
 #include "vocabulary/lessonmodel.h"
 #include "vocabulary/wordtypemodel.h"
-//#include "vocabulary/leitnerview.h"
-//#include "vocabulary/leitnermodel.h"
+#include "vocabulary/leitnerview.h"
+#include "vocabulary/leitnermodel.h"
 
 #include "entry-dialogs/multiplechoicewidget.h"
 #include "entry-dialogs/comparisonwidget.h"
@@ -42,6 +42,7 @@
 
 #include "settings/parleyprefs.h"
 #include "settings/languageproperties.h"
+#include "settings/documentproperties.h"
 #include "prefs.h"
 
 #include "scripts/scriptdialog.h"
@@ -88,11 +89,6 @@ Editor::~Editor()
     saveMainWindowSettings(cfg);
 }
 
-void Editor::updateScriptMenu()
-{
-    m_scriptManager->reloadActions();
-}
-
 void Editor::updateDocument()
 {
 ///@todo we can use connect here
@@ -101,7 +97,7 @@ void Editor::updateDocument()
 
     m_lessonModel->setDocument(m_mainWindow->parleyDocument()->document());
     m_wordTypeModel->setDocument(m_mainWindow->parleyDocument()->document());
-//    m_leitnerModel->setDocument(m_mainWindow->parleyDocument()->document());
+    m_leitnerModel->setDocument(m_mainWindow->parleyDocument()->document());
 
     if (!m_mainWindow->parleyDocument()->document()) {
         return;
@@ -112,7 +108,7 @@ void Editor::updateDocument()
     m_wordTypeView->expandToDepth(0);
 
     // the top level container of this model only holds the others
-//    m_leitnerView->setRootIndex(m_leitnerModel->index(0,0));
+    m_leitnerView->setRootIndex(m_leitnerModel->index(0,0));
 
     connect(m_mainWindow->parleyDocument()->document(), SIGNAL(docModified(bool)), m_mainWindow, SLOT(slotUpdateWindowCaption()));
     connect(m_vocabularyModel, SIGNAL(documentChanged(KEduVocDocument*)),
@@ -131,6 +127,7 @@ void Editor::updateDocument()
 //     new ModelTest(m_vocabularyModel, this);
 }
 
+
 void Editor::initDockWidgets()
 {
 // Lesson dock
@@ -189,27 +186,27 @@ void Editor::initDockWidgets()
         m_wordTypeView, SLOT(setTranslation(KEduVocExpression*, int)));
 
 // Leitner boxes dock
-//    QDockWidget* leitnerDockWidget = new QDockWidget(i18n("Grade Boxes"), this);
-//    leitnerDockWidget->setObjectName( "LeitnerDock" );
-//    m_leitnerView = new LeitnerView(this);
-//    leitnerDockWidget->setWidget(m_leitnerView);
-//    addDockWidget( Qt::LeftDockWidgetArea, leitnerDockWidget );
-//    m_dockWidgets.append(leitnerDockWidget);
+    QDockWidget* leitnerDockWidget = new QDockWidget(i18n("Grade Boxes"), this);
+    leitnerDockWidget->setObjectName( "LeitnerDock" );
+    m_leitnerView = new LeitnerView(this);
+    leitnerDockWidget->setWidget(m_leitnerView);
+    addDockWidget( Qt::LeftDockWidgetArea, leitnerDockWidget );
+    m_dockWidgets.append(leitnerDockWidget);
 
-//    m_leitnerModel = new LeitnerModel(this);
-//    leitnerDockWidget->setVisible(false);
-//    actionCollection()->addAction("show_leitner_dock", leitnerDockWidget->toggleViewAction());
+    m_leitnerModel = new LeitnerModel(this);
+    leitnerDockWidget->setVisible(false);
+    actionCollection()->addAction("show_leitner_dock", leitnerDockWidget->toggleViewAction());
 
-//    m_leitnerView->setModel(m_leitnerModel);
+    m_leitnerView->setModel(m_leitnerModel);
 
-//    connect(m_leitnerView, SIGNAL(selectedLeitnerBoxChanged(KEduVocLeitnerBox*)),
-//        m_vocabularyModel, SLOT(setLeitnerBox(KEduVocLeitnerBox*)));
+    connect(m_leitnerView, SIGNAL(selectedLeitnerBoxChanged(KEduVocLeitnerBox*)),
+        m_vocabularyModel, SLOT(setLeitnerBox(KEduVocLeitnerBox*)));
 
-//    connect(m_leitnerView, SIGNAL(signalShowContainer(KEduVocContainer*)),
-//        m_vocabularyModel, SLOT(showContainer(KEduVocContainer*)));
+    connect(m_leitnerView, SIGNAL(signalShowContainer(KEduVocContainer*)),
+        m_vocabularyModel, SLOT(showContainer(KEduVocContainer*)));
 
-//    connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
-//        m_leitnerView, SLOT(setTranslation(KEduVocExpression*, int)));
+    connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
+        m_leitnerView, SLOT(setTranslation(KEduVocExpression*, int)));
 
 // Conjugations
     QDockWidget *conjugationDock = new QDockWidget(i18n("Conjugation"), this);
@@ -374,6 +371,16 @@ void Editor::initDockWidgets()
 
 void Editor::initActions()
 {
+    KAction* uploadFile =new KAction(this);
+    actionCollection()->addAction("file_upload", uploadFile);
+    uploadFile->setIcon(KIcon("get-hot-new-stuff"));
+    uploadFile->setText(i18n("&Upload Vocabulary Document..."));
+    uploadFile->setWhatsThis(i18n("Share the current vocabulary collection with other users."));
+    uploadFile->setToolTip(uploadFile->whatsThis());
+    uploadFile->setStatusTip(uploadFile->whatsThis());
+    connect(uploadFile, SIGNAL(triggered()), m_mainWindow->parleyDocument(), SLOT(uploadFile()));
+
+
     KAction* editLanguages =new KAction(this);
     actionCollection()->addAction("edit_languages", editLanguages);
     editLanguages->setIcon(KIcon("set-language"));
@@ -549,20 +556,34 @@ void Editor::initScripts()
 
     //Load scripts
     m_scriptManager->loadScripts();
-    m_scriptManager->reloadScripts();
 }
 
-ParleyMainWindow* Editor::mainWindow()
+void Editor::saveState()
 {
-    return m_mainWindow;
+    m_vocabularyView->saveColumnVisibility();
 }
 
 void Editor::slotLanguageProperties()
 {
-    LanguageProperties properties(m_mainWindow->parleyDocument(), this);
+    LanguageProperties properties(this);
     if ( properties.exec() == KDialog::Accepted ) {
          m_vocabularyModel->resetLanguages();
     }
 }
 
+void Editor::slotDocumentProperties()
+{
+    DocumentProperties* titleAuthorWidget = new DocumentProperties(ParleyDocument::instance()->document(), false, this);
+    KDialog* titleAuthorDialog;
+    titleAuthorDialog = new KDialog(this);
+    titleAuthorDialog->setMainWidget( titleAuthorWidget );
+
+    // the language options are only shown, when this is used to create a new document.
+    titleAuthorWidget->languageGroupBox->setVisible(false);
+    titleAuthorDialog->setCaption(i18nc("@title:window document properties", "Properties for %1", ParleyDocument::instance()->document()->url().url()));
+    connect(titleAuthorDialog, SIGNAL(accepted()), titleAuthorWidget, SLOT(accept()));
+    titleAuthorDialog->exec();
+    delete titleAuthorDialog;
+}
+
 #include "editor.moc"
